globals [
  linha           ;; frente de óleo percolado
  oleo-total      ;; quantidade de solo saturado com óleo
                  ;; desde início de simulação
]

to preparar
  clear-all
  set oleo-total 0
  ask patches [
    set pcolor brown     ;; óleo não saturado    
    if (pxcor = max-pxcor)     
      [ set pcolor yellow ]  ;; coloca fronteira no lado direito do ecrã
                             ;; previne que óleo salte a fronteira
  ]
  set linha patches with [pycor = max-pycor]
  ask linha [
   if (pxcor mod 2 = 0) and (pcolor != yellow)
      [ set pcolor red ]  ;; inicializa uma linha de óleo
                          ;; representada por patches vermelhos
  ]
  do-plot
  reset-ticks
end

to executar
  if not any? linha with [pcolor = red]
    [ stop ]
  percolar
  do-plot
  verificar
  tick
end

to percolar
  ask linha with [pcolor = red] [
    ;; óleo percola para os dois patches a sudeste e sudoeste
    ask patches at-points [[-1 -1] [1 -1]]
      [ if (pcolor = brown) and (random-float 100 < porosidade)
          [ set pcolor red ] ]
    set pcolor black
    set oleo-total oleo-total + 1
  ]
  set linha patch-set [patch-at 0 -1] of linha
end

to verificar ;; caso óleo atinja margem inferior do ecrã este é apagado
            ;; e simulação continua no topo
  if [pycor] of one-of linha = max-pycor
    [ 
      display
      ask patches with [pcolor = black]
        [ set pcolor brown ] ]
end

to do-plot
  set-current-plot "Óleo Percolado"
  plot count linha with [pcolor = red]
  set-current-plot "Terra Contaminada"
  plot oleo-total
end

; Versão ICES Copyright 2004, Centro de Física Teórica e Computacional

; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the project: CONNECTED MATHEMATICS:
; MAKING SENSE OF COMPLEX PHENOMENA THROUGH BUILDING OBJECT-BASED PARALLEL
; MODELS (OBPML).  The project gratefully acknowledges the support of the
; National Science Foundation (Applications of Advanced Technologies
; Program) -- grant numbers RED #9552950 and REC #9632612.
;
; Copyright 1997 by Uri Wilensky. All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; This model was converted to NetLogo as part of the project:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS.  The project gratefully acknowledges the support of the
; National Science Foundation (REPP program) -- grant number REC #9814682.
; Converted from StarLogoT to NetLogo, 2001.  Updated 2002.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (1997).  NetLogo Diffusion Graphics model.
; http://ccl.northwestern.edu/netlogo/models/DiffusionGraphics.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 1998 by Uri Wilensky.  All rights reserved.  See
; http://ccl.northwestern.edu/netlogo/models/DiffusionGraphics
; for terms of use.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
233
30
629
600
100
140
1.9204
1
10
1
1
1
0
1
1
1
-100
100
-140
140
0
0
1
tempo
30.0

BUTTON
8
16
89
49
preparar
preparar
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
103
16
192
49
executar
executar
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
4
90
195
123
porosidade
porosidade
0.0
99.0
64.5
0.5
1
%
HORIZONTAL

PLOT
5
126
226
298
Óleo Percolado
tempo
óleo
0.0
30.0
0.0
50.0
true
false
"" ""
PENS
"default" 1.0 0 -2674135 true "" ""

PLOT
5
301
226
473
Terra Contaminada
tempo
óleo total
0.0
30.0
0.0
400.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

BUTTON
8
55
158
88
executar uma vez
executar
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

@#$#@#$#@
Introdução

Este modelo simula a infiltração de uma quantidade de óleo derramado em solos permeáveis. O modelo baseia-se numa versão simples de percolação dirigida.

O tipo de fluxo e a extensão do derrame dependem da porosidade do solo, que determina a probabilidade de percolação. O comportamento do sistema depende críticamente desta probabilidade. O modelo é caracterizado por dois regimes: fluxos contínuos (derrames extensos) para porosidades elevadas

e fluxos superficiais (derrames confinados) para porosidades baixas.  

A transição entre os dois regimes é rápida e ocorre numa gama estreita de porosidades.
 

Utilização

O óleo derramado é representado por patches vermelhos (gotas de óleo) que ocupam toda a largura no topo da caixa de simulação.

As gotas infiltram-se no solo, na diagonal, para a direita e para a esquerda, com uma probabilidade que varia entre zero e um. Esta probabilidade é determinada pela porosidade do solo que pode ser escolhida pelo utilizador.

Os patches castanhos representam o solo através do qual o óleo flui sob a acção da gravidade. A porosidade caracteriza a maior ou menor resistência do solo ao fluxo de óleo: é nula nos solos impermeáveis e 100% no limite oposto.

A probabilidade de infiltração aumenta com a porosidade do solo. Quanto mais permeável for o solo maior é a probabilidade do óleo atingir as camadas mais profundas. A propagação do fluido num meio poroso chama-se percolação.

O Netlogo usa condições de fronteira periódicas, pelo que o óleo que chega ao fundo da caixa de simulação pode continuar a infiltrar-se a partir do topo.

O programa pára automaticamente quando a frente de óleo deixa de avançar.

Os gráficos mostram a extensão da frente de óleo (vermelho) e a quantidade de solo saturado/contaminado (preto).

   
Questões

1) Corra simulações para diferentes valores da porosidade. O que observa nos padrões de solo contaminado ? Como dependem da porosidade ? 

2) Determine os valores da porosidade para os quais a percolação é contínua e os valores para os quais a frente de óleo pára. 

3) Observe o tamanho da frente de óleo. O valor final desta frente é o mesmo ? Ou depende da porosidade ?

4) Finalmente observe a quantidade de solo contaminado. Para solos (muito) porosos esta quantidade pode ser estimada fácilmente. Adivinhe como. Verifique utilizando os valores registados no gráfico. O que acontece no outro limite, para solos quase impermeáveis ?

5) A região intermédia, com porosidade á volta de 64,5%, é a mais interessante. Para esta porosidade o sistema (infinito) exibe uma transição de percolação, que separa o regime de fluxos contínuos (derrames extensos) do regime de fluxos superficiais (derrames confinados). Corra várias simulações para este valor da porosidade. Observe os padrões de solo contaminado. Como depende a quantidade de solo contaminado da largura da caixa e do tempo de simulação ? 

NOTA:Na transição de percolação o solo contaminado forma um agregado fractal, ao contrário do que acontece quando a porosidade é suficientemente elevada. Constatação do facto

Variantes e Extensões

Adicione um slider que permita controlar a quantidade de óleo derramada e use este parâmetro para prever a profundidade a que uma determinada quantidade de óleo pode chegar, para um dado tipo de solo. Repita as simulações para tipos de solos diferentes.

Torne o modelo mais realista fazendo a porosidade depender da profundidade do solo. Repita as simulações. Observa algumas diferenças relativamente ao modelo original ? 

Use a largura da caixa de simulação como um parâmetro adicional e verifique a dependência do fluxo nesta quantidade. 

Use a largura da caixa de simulação como um parâmetro adicional e verifique a dependência do fluxo nesta quantidade. 
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
setup
repeat screen-size-y - 1 [ go ]
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
