globals [ geracao energia-total ]
turtles-own [ energia ]
breed [ coelhos ]


to preparar
  clear-all
  set geracao 0
  set energia-total 0
  crescer-ervas
  set-default-shape coelhos "rabbit-shape"
  create-coelhos numero-inicial
  [ set color white
    setxy random-float world-width random-float world-height
    set energia random 10
    without-interruption
    [ set energia-total energia-total + energia ] ]
  preparar-grafico
  fazer-grafico
  reset-ticks
end

to executar
  crescer-ervas
  movimento
  fazer-grafico
  set geracao geracao + 1
  if not any? turtles
  [ stop ]
end

to movimento
  ask coelhos
  [ passo
    comer-erva
    comer-daninhas
    if reproducao?
    [ reproduzir ]
    morrer ]
end

to crescer-ervas
  ask patches with [ pcolor = black ]
  [ if random-float 1000 < crescimento-daninhas
    [ set pcolor violet ]
    if random-float 1000 < crescimento-erva
    [ set pcolor green ] ]
end

to passo
  rt random-float 50
  lt random-float 50
  forward 1
  set energia energia - 0.5
  set energia-total energia-total - 0.5
end

to comer-erva
  if pcolor = green
  [ set pcolor black
    set energia energia + energia-erva
    set energia-total energia-total + energia-erva ]
end

to comer-daninhas
  if pcolor = violet
  [ set pcolor black
    set energia energia + energia-daninhas
    set energia-total energia-total + energia-daninhas ]
end

to reproduzir
  if energia > limite-reproducao
  [ set energia energia / 2
    hatch 1
    [ forward 1 ] ]
end

to morrer
  if energia <= 0
  [ without-interruption
    [ set energia-total energia-total - energia ]
      die ]
end

to fazer-grafico
  set-current-plot "Populacoes"
  set-current-plot-pen "erva"
  plot count patches with [ pcolor = green ] / 4
  set-current-plot-pen "coelhos"
  plot count turtles
  set-current-plot-pen "daninhas"
  plot count patches with [ pcolor = violet ] / 4
end

to preparar-grafico
  set-current-plot "Populacoes"
  set-plot-y-range 0 numero-inicial
end

; Versão ICES Copyright 2004, Centro de Física Teórica e Computacional

; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the project:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS.  The project gratefully acknowledges the support of the
; National Science Foundation (REPP program) -- grant number REC #9814682.
;
; Copyright 2001 by Uri Wilensky.  Updated 2001.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2001).  NetLogo L-SystemFractals model.
; http://ccl.northwestern.edu/netlogo/models/L-SystemFractals.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 1998 by Uri Wilensky.  All rights reserved.  See
; http://ccl.northwestern.edu/netlogo/models/L-SystemFractals
; for terms of use.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
313
12
757
477
15
15
14.0
1
10
1
1
1
0
1
1
1
-15
15
-15
15
0
0
0
NIL
30.0

BUTTON
3
40
95
73
preparar
preparar
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
98
40
187
73
executar
executar
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
2
108
150
141
crescimento-erva
crescimento-erva
0.0
20.0
7
1.0
1
NIL
HORIZONTAL

SLIDER
2
141
150
174
crescimento-daninhas
crescimento-daninhas
0.0
20.0
0
1.0
1
NIL
HORIZONTAL

SLIDER
152
108
310
141
energia-erva
energia-erva
0.0
10.0
3
0.5
1
NIL
HORIZONTAL

SLIDER
152
141
310
174
energia-daninhas
energia-daninhas
0.0
10.0
0
0.5
1
NIL
HORIZONTAL

SLIDER
2
75
150
108
numero-inicial
numero-inicial
0.0
500.0
50
1.0
1
NIL
HORIZONTAL

SLIDER
152
75
310
108
limite-reproducao
limite-reproducao
0.0
20.0
17
1.0
1
NIL
HORIZONTAL

PLOT
3
176
310
372
Populacoes
Geracao
Pop
0.0
100.0
0.0
111.0
true
true
"" ""
PENS
"erva" 1.0 0 -11352576 true "" ""
"coelhos" 1.0 0 -65536 true "" ""
"daninhas" 1.0 0 -8716033 true "" ""

MONITOR
380
487
469
532
coelhos
count coelhos
0
1
11

SWITCH
190
40
311
73
reproducao?
reproducao?
0
1
-1000

MONITOR
284
487
374
532
NIL
geracao
0
1
11

MONITOR
476
487
552
532
erva
count patches with [ pcolor = green ]
0
1
11

MONITOR
560
487
642
532
daninhas
count patches with [ pcolor = violet ]
0
1
11

MONITOR
648
487
758
532
NIL
energia-total
3
1
11

@#$#@#$#@
INTRODUÇÃO

Este modelo explora um ecosistema simples composto por coelhos, erva, e daninhas. Os coelhos deslocam-se aleatoriamente, e as ervas e daninhas crescem aleatoriamente. Quando um coelho encontra alguma erva ou daninhas, come-a e ganha energia. Se o coelho ganhar energia suficiente, reproduz-se. Caso contrário, acaba por morrer.

A erva e as daninhas podem ser ajustadas para crescerem a ritmos diferentes e para darem aos coelhos quantidades de energia diferentes. O modelo pode ser usado para investigar as vantagens competitivas destas variáveis.

UTILIZAÇÃO

Observe o mostrador COELHOS, que conta o número de coelhos em existência, e o gráfico para ver como a população de coelhos evolui com o tempo.

No início, não existe erva suficiente para todos os coelhos, e muitos morrem. Mas isso permite que a erva cresça livremente, fornecendo comida abundante para os coelhos que ficam. Esses coelhos ganham energia suficiente e reproduzem-se. O maior número de coelhos leva de novo à falta de erva, e o ciclo recomeça.

A população de coelhos segue uma oscilação amortecida (o mesmo acontece com a quantidade de erva), eventualmente estabilizando num intervalo pequeno. As oscilações da população de coelhos e da quantidade de erva encontram-se desfasadas uma da outra. Estas oscilações desfasadas são características de sistemas predador/presa.

QUESTÕES

1. Com a simulação a correr, aumente o valor do parâmetro CRESCIMENTO-ERVA e deixe o sistema estabilizar. Como é que isto influencia a quantidade de erva e a população de coelhos?

2. Modifique agora o LIMITE-REPRODUCAO. Como é que isto afecta os níveis de coelhos e de erva (após estabilização)?

3. Com os parâmetros actuais, a população de coelhos sofre uma oscilação amortecida (a amplitude das oscilações diminui com o tempo). Modificando os parâmetros, é possível criar uma oscilação de amplitude constante? Ou uma oscilação instável?

4. Acrescente agora daninhas fazendo CRESCIMENTO-DANINHAS e ENERGIA-DANINHAS iguais a CRESCIMENTO-ERVA e ENERGIA-ERVA, respectivamente. Corra a simulação e note que as populações de ervas e daninhas são aproximadamente iguais. O que acontece ao fazer as ervas e as daninhas crescerem a ritmos diferentes?

5. E o que acontece se as daninhas crescerem ao mesmo ritmo das ervas, mas fornecerem menos energia aos coelhos (ENERGIA-DANINHAS for menor que ENERGIA-ERVA)?

6. Com o modelo a correr, altere subitamente LIMITE-REPRODUCAO para zero. O que acontece?

VARIANTES E EXTENSÕES

Introduza uma distribuição de erva não uniforme (por exemplo divida a janela gráfica em duas ou mais regiões com taxas de crescimento de erva diferentes) e observe alterações qualitativas na evolução do sistema (nomeadamente na distribuição dos coelhos).
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

bunny-shape
false
0
Circle -7500403 true true 59 56 186
Circle -7500403 true true 17 55 91
Circle -7500403 true true 194 197 46
Circle -7500403 true true 33 182 59
Circle -7500403 true true 219 104 47
Polygon -7500403 true true 56 56 111 5 119 27 91 68

rabbit-shape
false
0
Circle -7500403 true true 75 134 150
Polygon -7500403 true true 124 164 78 113 62 56 70 0 107 38 124 91
Polygon -7500403 true true 170 159 160 95 173 39 219 0 223 51 208 116

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
